\name{00Intro.setRNG}
\alias{00Intro.setRNG}
\title{setRNG}

\section{Usage}{
   library("setRNG") 
}

\description{
  Programs to set random number generator (and seed) in R and S.}
\section{Introduction}{
This library provides tools to reset the (normal) random number generator to a
reproducible state. It uses the R/S tools for setting the seed, but also sets
the mechanism for converting uniform numbers to normally distributed numbers.

The library also implements an approach to random number generation 
which allows the same random experiments to be replicated in S and R.
As of R 1.0.1 this adds nothing to R except for the function setRNG which sets
both RNGkind and the seed. The functions allow the R results using 
Wichmann-Hill and Box-Muller to be replicated in S.
These functions are intended primarily as a way to confirm that other code works in 
the same way in both S and R, not as an improved RNG. Default and other
RNGs can  still be used and are probably preferred for both speed and 
theoretical reasons. The present version of this works only for uniform 
and normal distributions. These were done with the aid of an example 
from B. D. Ripley.

The files in the S/ subdirectory of the package are for use with S (not R).
}
  

\examples{
is.R()
setRNG(kind="Wichmann-Hill", seed=c(979,1479,1542), normal.kind="Box-Muller")
rnorm(10)
}
\keyword{programming}
\keyword{interface}
\keyword{utilities}
\keyword{distribution}

\eof
\name{getRNG}
\alias{getRNG}
\alias{getRNG.default}

\title{get the RND and seed from an object}
\description{
Get the random number generator and seed used to generate an object.
}
\usage{
    getRNG(e=NULL)
    \method{getRNG}{default}(e=NULL)
}
\arguments{
    \item{e}{an object generated by simulation (which stored the RNG 
    information).}
}
\value{The random seed and other random number generation information
   used to generate the object. }
\details{Some information about the version is also verified.}
\seealso{
\code{\link{setRNG}},
\code{\link{.Random.seed}}
}
\examples{
\dontrun{
if (require("dse1")) {
  if(is.R()) data("eg1.DSE.data.diff", package="dse1")
  model <- estVARXls(eg1.DSE.data.diff)
  sim <- simulate(model)
  getRNG(sim)
  }
}
}
%\keyword{DSE}
\keyword{ts}
\eof
\name{setRNG}
\alias{setRNG}
\alias{RNGkind}
\alias{random.number.test}
\title{Set the random number generator}
\description{Set the random number generator.}
\usage{
    setRNG(kind=NULL, seed=NULL, normal.kind=NULL)
    random.number.test()
    }
\arguments{None required
    \item{kind}{a character string.}
    \item{seed}{a vector of numbers (depending on kind).}
    \item{normal.kind}{a character string.}
}
\value{The old setting.}
\details{
    Sets the uniform and normal random number generators and the seed.
    The function \code{random.number.test()} can be used to check that the
    function is working properly. The old setting is returned in a format
    which can be used in another call to setRNG. (This would reset to the
    original value.) If no arguments are given the current setting is 
    returned. In R see RNGkind for more details.
}
\sideffects{Sets global variables controlling the uniform and normal random 
    number generators and the global seed.}
\seealso{
    \code{\link{set.seed}}
    \code{\link{RNGkind}}
    \code{\link{runif}}
    \code{\link{rnorm}}
}
\examples{
setRNG(kind="Wichmann-Hill", seed=c(979,1479,1542), normal.kind="Box-Muller")
rnorm(10)
}
\keyword{programming}
\keyword{utilities}

\eof
